@@ -30,6 +30,7 @@ It was written by Pabs.
 /* System headers */
 
 #include <sys/types.h>
+#include <string.h>
 #include <time.h>
 
 
@@ -210,3 +211,24 @@ char* make_FILETIME_string( FILETIME ts ){
 }
 
 #endif /* 0 */
+
+void print_with_entity_refs( FILE* f, char* str ){
+	size_t l = 0;
+	char* s = str;
+	for(;;){
+		l = strcspn(s,"&<>\"\x99");
+		fwrite( s, l, 1, f );
+		switch((unsigned char)*(s+l)){
+			case '&': fputs( "&amp;", f ); break;
+			case '<': fputs( "&lt;", f ); break;
+			case '>': fputs( "&gt;", f ); break;
+			case '"': fputs( "&quot;", f ); break;
+			case 0x99: fputs( "&trade;", f ); break;
+			case 0: return;
+			default:
+				fprintf( stderr, "%s: %s\n", PROGNAME, "buggy implementation of strcspn detected" );
+				fputc( *(s+l), f );
+		}
+		s += l+1;
+	}
+}
