@@ -120,7 +120,7 @@ void recreate_hhp( void ){
 			/* FIXME: Print something else when we get its dumping */
 			if( input ){
 				char* fn = strrchr( input, '/' );
-				fprintf( hhp, ";Input: %s\r\n", fn ? fn : input );
+				fprintf( hhp, ";Input: %s\r\n", fn ? fn+1 : input );
 			}
 
 			{ /* Compiler name */
@@ -145,6 +145,7 @@ void recreate_hhp( void ){
 				}
 			}
 
+#if 0 /* This QWORD is totally fucked up */
 			/* Compilation date (FILETIME) */
 			if(got_stuff){
 				char* compilation_FILETIME_string = make_FILETIME_string(compilation_FILETIME);
@@ -152,6 +153,7 @@ void recreate_hhp( void ){
 				else fprintf( hhp, ";Compilation date: %llu00 nano-seconds after 0:00 Jan 1 1600\r\n", compilation_FILETIME );
 				/* FREE(compilation_FILETIME_string); */
 			}
+#endif /* 0 */
 
 			/* Operating system language */
 			if( lcid_success ){
@@ -399,6 +401,7 @@ void recreate_hhp( void ){
 		no_files_yet = true;
 		print_files(".");
 		FREE(prefix);
+		prefix_len = prefix_size = 0;
 
 		/* [ALIAS], [MAP] */
 		if( alias_map_success ){
@@ -568,5 +571,5 @@ void print_files( char* d ){
 
 		closedir( dir );
 	} else
-		fprintf( stderr, "%s: %s/%s/%s: %s\n", PROGNAME, input, prefix, d, strerror(errno) );
+		fprintf( stderr, "%s: %s/%s/%s: %s\n", PROGNAME, input, prefix?prefix:"", d, strerror(errno) );
 }
